==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/MaxByEvaluation.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;

using com.db4o.query;

namespace com.db4o.test
{
    public class MaxByEvaluation
    {
        static int MAX = 20;

        public int val;

        public void store()
        {
            for(int i = 0; i <= MAX; i++)
            {
                MaxByEvaluation mbe = new MaxByEvaluation();
                mbe.val = i;
                Tester.store(mbe);
            }
        }

        public void test()
        {
            Query q = Tester.query();
            q.constrain(typeof(MaxByEvaluation));
            q.descend("val").constrain(new EvalCallbackForMax());
            ObjectSet objectSet = q.execute();
            Tester.ensure(objectSet.size() == 1);
            MaxByEvaluation mbe = (MaxByEvaluation)objectSet.next();
            Tester.ensure(mbe.val == MAX);
        }
    }

    public class EvalCallbackForMax : Evaluation
    {
        private int currentMax;
        private Candidate currentCandidate;

        public void evaluate(Candidate candidate)
        {
            int current = (int)candidate.getObject();
            if(currentCandidate != null)
            {
                if(currentMax > current)
                {
                    candidate.include(false);
                    return;
                }
                currentCandidate.include(false);
            }
            candidate.include(true);
            currentCandidate = candidate;
            currentMax = current;
        }
    }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/MaxByEvaluation.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;

using com.db4o.query;

namespace com.db4o.test
{
    public class MaxByEvaluation
    {
        static int MAX = 20;

        public int val;

        public void Store()
        {
            for(int i = 0; i <= MAX; i++)
            {
                MaxByEvaluation mbe = new MaxByEvaluation();
                mbe.val = i;
                Tester.Store(mbe);
            }
        }

        public void Test()
        {
            Query q = Tester.Query();
            q.Constrain(typeof(MaxByEvaluation));
            q.Descend("val").Constrain(new EvalCallbackForMax());
            ObjectSet objectSet = q.Execute();
            Tester.Ensure(objectSet.Size() == 1);
            MaxByEvaluation mbe = (MaxByEvaluation)objectSet.Next();
            Tester.Ensure(mbe.val == MAX);
        }
    }

    public class EvalCallbackForMax : Evaluation
    {
        private int currentMax;
        private Candidate currentCandidate;

        public void Evaluate(Candidate candidate)
        {
            int current = (int)candidate.GetObject();
            if(currentCandidate != null)
            {
                if(currentMax > current)
                {
                    candidate.Include(false);
                    return;
                }
                currentCandidate.Include(false);
            }
            candidate.Include(true);
            currentCandidate = candidate;
            currentMax = current;
        }
    }
}
